@@ -186,7 +186,9 @@ class NumericPreModelAnalysis:
             sample_features = self.n_cols
         else:
             sample_features = min(2 * 25, int(self.n_cols / 2))
-        top_feature_names = random.sample(self.cols_sorted[0:sample_features], top_features)
+        print("top_features", top_features)
+        print("sample_features", len(self.cols_sorted[0:sample_features]))
+        top_feature_names = random.sample(self.cols_sorted[0:top_features], sample_features)
         feature_index = {feature: index for index, feature in enumerate(self.cols_sorted)}
         top_feature_names.sort(key=lambda x: feature_index[x])
 
@@ -207,7 +209,7 @@ class NumericPreModelAnalysis:
                 ax_i.set_title(col, fontweight='bold', transform=ax_i.transAxes, y=0.5)
             plt.show()
             plt.close()
-        if self.data_info.problem_type_val in ["Regression"]:
+        elif self.data_info.problem_type_val in ["Regression"]:
             plt.suptitle("Partial Plot to Identify Patterns between Sampled Numeric Features and Target", fontsize=16,
                          fontweight='bold')
             for i, col in enumerate(top_feature_names[:top_features]):
@@ -253,7 +255,6 @@ class NumericPreModelAnalysis:
                     plt.xlabel(None)
             plt.show()
             plt.close()
-        plt.close()
 
     def run(self, plot=True):
         if self.n_cols > 1:
